@@ -5,8 +5,10 @@
 #![doc = include_str ! ("../readme.md")]
 
 mod builder;
+mod macros;
 mod systems;
 mod traits;
+
 pub use self::{
     builder::TailwindBuilder,
     systems::{
@@ -15,9 +17,10 @@ pub use self::{
         fonts::FontSystem,
         layouts::{TailWindZIndex, TailwindAspect, TailwindBreak},
         preflight::PreflightSystem,
-        sizes::{TailwindMaxWidth, TailwindMinWidth, TailwindWidth},
-        TailwindObject, TailwindParsed,
+        sizes::{TailwindSizing, TailwindWidth},
+        TailwindObject, ParsedItem,
+        tables::{TailwindTableLayout, TailwindBorderCollapse},
     },
-    traits::TailwindInstance,
+    traits::{CssAttribute, TailwindInstance},
 };
 pub use tailwind_error::{Result, TailwindError, TailwindErrorKind};
