@@ -11,7 +11,15 @@ impl TailwindAspect {
     pub fn new(kind: &'static str, ratio: &'static str) -> Box<dyn TailwindInstance> {
         Box::new(Self { kind, ratio })
     }
-    pub fn parser<'a>(kind: &'static str, ratio: &'static str) -> impl Fn(&'a str) -> TailwindParsed {
+    pub fn parser<'a>() -> impl FnMut(&'a str) -> ParsedList<'a> {
+        move |input| as_list(alt((
+            // https://tailwindcss.com/docs/aspect-ratio
+            Self::parser_kind("auto", "auto"),
+            Self::parser_kind("square", "1 / 1"),
+            Self::parser_kind("video", "16 / 9"),
+        ))(input))
+    }
+    pub fn parser_kind<'a>(kind: &'static str, ratio: &'static str) -> impl FnMut(&'a str) -> ParsedItem<'a> {
         let id = format!("aspect-{}", kind);
         move |input| match tag(id.as_str())(input) {
             Ok(o) => Ok((o.0, Self::new(kind, ratio))),
@@ -20,47 +28,51 @@ impl TailwindAspect {
     }
 }
 
+
 impl TailwindBreak {
-    pub fn parser<'a>() -> impl FnMut(&'a str) -> TailwindParsed {
-        alt((
-            Self::parser_before("auto"),
-            Self::parser_before("avoid"),
-            Self::parser_before("all"),
-            Self::parser_before("avoid-page"),
-            Self::parser_before("page"),
-            Self::parser_before("left"),
-            Self::parser_before("right"),
-            Self::parser_before("column"),
-            Self::parser_after("auto"),
-            Self::parser_after("avoid"),
-            Self::parser_after("all"),
-            Self::parser_after("avoid-page"),
-            Self::parser_after("page"),
-            Self::parser_after("left"),
-            Self::parser_after("right"),
-            Self::parser_after("column"),
-            Self::parser_inside("auto"),
-            Self::parser_inside("avoid"),
-            Self::parser_inside("avoid-page"),
-            Self::parser_inside("avoid-column"),
-        ))
+    pub fn parser<'a>() -> impl FnMut(&'a str) -> ParsedList<'a> {
+        move |input| as_list(alt((
+            // https://tailwindcss.com/docs/break-before
+            TailwindBreak::parser_before("auto"),
+            TailwindBreak::parser_before("avoid"),
+            TailwindBreak::parser_before("all"),
+            TailwindBreak::parser_before("avoid-page"),
+            TailwindBreak::parser_before("page"),
+            TailwindBreak::parser_before("left"),
+            TailwindBreak::parser_before("right"),
+            TailwindBreak::parser_before("column"),
+            // https://tailwindcss.com/docs/break-after
+            TailwindBreak::parser_after("auto"),
+            TailwindBreak::parser_after("avoid"),
+            TailwindBreak::parser_after("all"),
+            TailwindBreak::parser_after("avoid-page"),
+            TailwindBreak::parser_after("page"),
+            TailwindBreak::parser_after("left"),
+            TailwindBreak::parser_after("right"),
+            TailwindBreak::parser_after("column"),
+            // https://tailwindcss.com/docs/break-inside
+            TailwindBreak::parser_inside("auto"),
+            TailwindBreak::parser_inside("avoid"),
+            TailwindBreak::parser_inside("avoid-page"),
+            TailwindBreak::parser_inside("avoid-column"),
+        ))(input))
     }
 
-    pub fn parser_before<'a>(kind: &'static str) -> impl Fn(&'a str) -> TailwindParsed {
+    pub fn parser_before<'a>(kind: &'static str) -> impl FnMut(&'a str) -> ParsedItem {
         let id = format!("break-before-{}", kind);
         move |input| match tag(id.as_str())(input) {
             Ok(o) => Ok((o.0, Box::new(Self::Before(kind)))),
             Err(e) => Err(e),
         }
     }
-    pub fn parser_after<'a>(kind: &'static str) -> impl Fn(&'a str) -> TailwindParsed {
+    pub fn parser_after<'a>(kind: &'static str) -> impl FnMut(&'a str) -> ParsedItem {
         let id = format!("break-after-{}", kind);
         move |input| match tag(id.as_str())(input) {
             Ok(o) => Ok((o.0, Box::new(Self::After(kind)))),
             Err(e) => Err(e),
         }
     }
-    pub fn parser_inside<'a>(kind: &'static str) -> impl Fn(&'a str) -> TailwindParsed {
+    pub fn parser_inside<'a>(kind: &'static str) -> impl FnMut(&'a str) -> ParsedItem {
         let id = format!("break-inside-{}", kind);
         move |input| match tag(id.as_str())(input) {
             Ok(o) => Ok((o.0, Box::new(Self::Inside(kind)))),
@@ -71,7 +83,7 @@ impl TailwindBreak {
 
 impl TailWindZIndex {
     #[inline]
-    fn number(n: usize, negative: bool) -> Box<dyn TailwindInstance> {
+    fn number(n: isize, negative: bool) -> Box<dyn TailwindInstance> {
         match negative {
             true => Box::new(Self::Negative(n)),
             false => Box::new(Self::Positive(n)),
@@ -81,11 +93,11 @@ impl TailWindZIndex {
     fn auto() -> Box<dyn TailwindInstance> {
         Box::new(Self::Auto)
     }
-    pub fn parser<'a>() -> impl FnMut(&'a str) -> TailwindParsed {
+    pub fn parser<'a>() -> impl FnMut(&'a str) -> ParsedItem {
         alt((Self::parse_number, Self::parse_auto))
     }
 
-    pub fn parse_number(input: &str) -> TailwindParsed {
+    pub fn parse_number(input: &str) -> ParsedItem {
         match tuple((
             //
             opt(tag("-")),
@@ -99,7 +111,7 @@ impl TailWindZIndex {
             Err(e) => Err(e),
         }
     }
-    pub fn parse_auto(input: &str) -> TailwindParsed {
+    pub fn parse_auto(input: &str) -> ParsedItem {
         match tuple((
             //
             tag("z"),
